@@ -614,6 +614,11 @@ dc1394_macosx_capture_dequeue (platform_camera_t * craw,
     dc1394video_frame_t * frame_tmp = capture->frames + next;
     char ch;
 
+	if(craw->frames==NULL || craw->capture_is_set==0) {
+		*frame=NULL;
+		return DC1394_CAPTURE_IS_NOT_SET;
+	}
+
     if ( (policy<DC1394_CAPTURE_POLICY_MIN) || (policy>DC1394_CAPTURE_POLICY_MAX) )
         return DC1394_INVALID_CAPTURE_POLICY;
 
